@@ -103,7 +103,7 @@ class Artifacts:
         self.entry_list: List[ArtifactEntry] = entry_list if entry_list else []
 
     # 해당 Artifacts의 파일을 다운로드 후에 key에 해당하는 객체를 찾아 객체로 복원해서 반환
-    def get(self, key: str = None) -> Union[str, Table, Image, Chart, list[Image]]:
+    def get(self, key: str = None) -> Union[str, Table, Image, Chart, List[Image]]:
         self.download()
 
         artifact_entry_list = [item for item in self.entry_list if item.key == key]
@@ -128,7 +128,7 @@ class Artifacts:
     # 추가된 각 항목에 대해서 ArtifactEntry를 생성한 후 Artifact가 가진 ArtifactEntry list에 추가함
     # name: 아티펙트에 각 엔트리의 식별자로 기록될 이름
     # data: 아티펙트에 추가될 데이터( Table  | Image | chart | file name | directory path | reference url )
-    def add(self, data: Union[str, Table, Image, Chart, list[Image]], name: str = None) -> None:
+    def add(self, data: Union[str, Table, Image, Chart, List[Image]], name: str = None) -> None:
         if isinstance(data, str):
             # if data is file_path
             data = os.path.relpath(data)  # Convert any path to a relative path
