@@ -328,7 +328,7 @@ def download_artifact():
     pass
 
 
-def login(key: str) -> bool:
+def login(key: str) -> (bool, str):
     rsp = http_interface.login(get_http_host(), key)
     if rsp["result"] == "success":
 
@@ -340,7 +340,11 @@ def login(key: str) -> bool:
         channel = grpc.insecure_channel(grpc_url)
         stub = ResourceStub(channel)
         set_stub(stub)
-    return rsp["result"] == "success"
+    if rsp["result"] == "success":
+        return True, rsp["token"]
+    else:
+        return False, None
+
 
 
 def init(exp_name: str = "", team_name: str = "", run_name: str = "", config: Dict = None) -> Dict:
